@@ -6,13 +6,19 @@ use warnings;
 	package Ask;
 	
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '0.004';
+	our $VERSION   = '0.005';
 	
 	use Carp qw(croak);
-	use File::Which qw(which);
 	use Moo::Role qw();
 	use Module::Runtime qw(use_module use_package_optimistically);
-	use namespace::sweep 0.006;
+	use Module::Pluggable (
+		search_path => 'Ask',
+		except      => [qw/ Ask::API Ask::Functions /],
+		inner       => 0,
+		require     => 0,
+		sub_name    => '__plugins',
+	);
+	use namespace::sweep;
 	
 	sub import {
 		shift;
@@ -23,66 +29,34 @@ use warnings;
 		}
 	}
 	
+	sub plugins {
+		__plugins(@_);
+	}
+	
 	sub detect {
 		my $class  = shift;
 		my %args   = @_==1 ? %{$_[0]} : @_;
 		
-		my $instance_class = $class->_detect_class_with_traits(\%args)
-			or croak "Could not establish an appropriate Ask backend";
-		
-		return $instance_class->new(\%args);
-	}
-	
-	my %_classes;
-	sub _detect_class_with_traits {
-		my ($class, $args) = @_;
-		my @traits = @{ delete($args->{traits}) // [] };
-		
-		my $instance_class = $class->_detect_class($args);
-		return unless defined $instance_class;
-		return $instance_class unless @traits;
-		
-		# Cache class
-		my $key = join q(|), $instance_class, sort @traits;
-		$_classes{$key} //= "Moo::Role"->create_class_with_roles(
-			$instance_class,
-			@traits,
-		);
-	}
-	
-	sub _detect_class {
-		my ($class, $args) = @_;
+		my @implementations =
+			reverse sort { $a->quality <=> $b->quality }
+			grep { use_package_optimistically($_)->DOES('Ask::API') }
+			$class->plugins;
 		
 		if (exists $ENV{PERL_ASK_BACKEND}) {
-			return use_package_optimistically($ENV{PERL_ASK_BACKEND});
+			@implementations = use_module($ENV{PERL_ASK_BACKEND});
+		}
+		elsif ($ENV{AUTOMATED_TESTING} or $ENV{PERL_MM_USE_DEFAULT} or not @implementations) {
+			@implementations = use_module('Ask::Fallback');
 		}
 		
-		if (exists $args->{class}) {
-			return use_package_optimistically(delete $args->{class});
+		my @traits = @{ delete($args{traits}) // [] };
+		for my $i (@implementations) {
+			my $k = @traits ? "Moo::Role"->create_class_with_roles($i, @traits) : $i;
+			my $self = eval { $k->new(\%args) } or next;
+			return $self if $self->is_usable;
 		}
 		
-		if (-t STDIN and -t STDOUT) {
-			return use_module("Ask::STDIO");
-		}
-		
-		if (eval { require Ask::Gtk }) {
-			return 'Ask::Gtk';
-		}
-		
-		if (eval { require Ask::Tk }) {
-			return 'Ask::Tk';
-		}
-		
-		if (eval { require Ask::Wx }) {
-			return 'Ask::Wx';
-		}
-		
-		if (my $zenity = which('zenity')) {
-			$args->{zenity} //= $zenity;
-			return use_module("Ask::Zenity");
-		}
-		
-		return;
+		croak "No usable backend for Ask";
 	}
 }
 
@@ -176,15 +150,21 @@ The C<text> argument is supported as a way of communicating what you'd like
 them to enter. The C<hide_text> argument can be set to true to I<hint> that
 the text entered should not be displayed on screen (e.g. password input).
 
+The C<default> argument can be used to supply a default return value if the
+user cannot be asked for some reason (e.g. running on an unattended terminal).
+
 =item C<< question(text => $text, %arguments) >>
 
-Ask the user to answer a affirmative/negative question (i.e. OK/cancel,
+Ask the user to answer an affirmative/negative question (i.e. OK/cancel,
 yes/no) defaulting to affirmative. Returns boolean.
 
 The C<text> argument is the text of the question; the C<ok_label> argument
 can be used to set the label for the affirmative button; the C<cancel_label>
 argument for the negative button.
 
+The C<default> argument can be used to supply a default return value if the
+user cannot be asked for some reason (e.g. running on an unattended terminal).
+
 =item C<< file_selection(%arguments) >>
 
 Ask the user for a file name. Returns the file name. No checks are made to
@@ -194,6 +174,10 @@ The C<multiple> argument can be used to indicate that multiple files may be
 selected (they are returned as a list); the C<directory> argument can be
 used to I<hint> that you want a directory.
 
+The C<default> argument can be used to supply a default return value if the
+user cannot be asked for some reason (e.g. running on an unattended terminal).
+If C<multiple> is true, then this must be an arrayref.
+
 =item C<< single_choice(text => $text, choices => \@choices) >>
 
 Asks the user to select a single option from many choices.
@@ -211,6 +195,13 @@ For example:
       ],
    );
 
+The choices are C<< identifier => label >> pairs. The identifiers are not
+necessarily displayed to the user making the choice; the labels are. The
+function returns the identifier for the chosen option.
+
+The C<default> argument can be used to supply a default return value if the
+user cannot be asked for some reason (e.g. running on an unattended terminal).
+
 =item C<< multiple_choice(text => $text, choices => \@choices) >>
 
 Asks the user to select zero or more options from many choices.
@@ -226,6 +217,12 @@ Asks the user to select zero or more options from many choices.
       ],
    );
 
+Returns list of identifiers.
+
+The C<default> argument can be used to supply a default return value if the
+user cannot be asked for some reason (e.g. running on an unattended terminal).
+It must be an arrayref.
+
 =back
 
 If you wish to create your own implementation of the Ask API, please
@@ -278,6 +275,10 @@ The C<PERL_ASK_BACKEND> environment variable can be used to influence the
 outcome of C<< Ask->detect >>. Indeed, it trumps all other factors. If set,
 it should be a full class name.
 
+If either of the C<AUTOMATED_TESTING> or C<PERL_MM_USE_DEFAULT> environment
+variables are set to true, the C<< Ask::Fallback >> backend will automatically
+be used.
+
 =head1 BUGS
 
 Please report any bugs to
@@ -287,7 +288,39 @@ L<http://rt.cpan.org/Dist/Display.html?Queue=Ask>.
 
 See L<Ask::API> for documentation of API internals.
 
-Bundled API implementations are L<Ask::STDIO>, L<Ask::Zenity> and L<Ask::Tk>.
+Bundled Ask API backends:
+
+=over
+
+=item *
+
+L<Ask::Callback> - implementation for testing; redirects input and output to callback functions.
+
+=item *
+
+L<Ask::Fallback> - returns default answers; for scripts running unattended.
+
+=item *
+
+L<Ask::Gtk> - GUI using L<Gtk2>.
+
+=item *
+
+L<Ask::STDIO> - based on STDIN/STDOUT/STDERR
+
+=item *
+
+L<Ask::Tk> - GUI using L<Tk>.
+
+=item *
+
+L<Ask::Wx> - GUI using L<Wx>.
+
+=item *
+
+L<Ask::Zenity> - GUI using the C<< /usr/bin/zenity >> binary (part of GNOME)
+
+=back
 
 Similar modules: L<IO::Prompt>, L<IO::Prompt::Tiny> and many others.
 
