@@ -6,7 +6,7 @@ use warnings;
 	package Ask::Tk;
 	
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '0.004';
+	our $VERSION   = '0.005';
 
 	use Moo;
 	use Tk;
@@ -14,6 +14,10 @@ use warnings;
 
 	with 'Ask::API';
 	
+	sub quality {
+		return 30;
+	}
+	
 	sub info {
 		my ($self, %o) = @_;
 		
